from setuptools import setup

setup(name='bin-gauss-distros',
      version='0.1',
      description='Binomial and Gaussian Distributions',
      packages=['bin-gauss-distros'],
      author = 'Cristian Iorga',
      author_email = 'ubik3000@gmail.com',
      zip_safe=False)
